Enum SubCommand

pub(crate) enum SubCommand {
    GrepDiff {
        commit: Option<GitHash>,
        target: Option<ProperDirname>,
        params: Option<String>,
        regex_start: String,
        regex_end: String,
        logfiles: Vec<PathBuf>,
    },
    PostProcessSingle {
        no_stats: bool,
        run_dir: PathBuf,
    },
    PostProcessSummary {
        single: bool,
        no_single_stats: bool,
        no_summary_stats: bool,
        key_dir: PathBuf,
    },
    Dev {
        subcommand: DevSubCommand,
    },
}

Variants



GrepDiff

Extract time differences between pairs of lines in log files from benchmarking runs–not the evobench.log files, but files with captured stdout/stderr, in the working directory pool directory (like $n.output_of_benchmarking_command_at_*).

Fields

commit: Option<GitHash>

Filter for commit id

target: Option<ProperDirname>

Filter for target name

params: Option<String>

Filter for custom parameters (environment variables); you can provide multiple separated by ‘/’, e.g. “FOO=1/BAR=hi”; not all of them need to be provided, the filter checks for existance and equality on those variables that are provided. NOTE: does not verify correct syntax of the variable names and values (currently no configuration is read, thus the info is not available) except for the basic acceptance rules for custom env var names.

regex_start: String

The regex to match a log line that starts a timed region

regex_end: String

The regex to match a log line that ends a timed region

logfiles: Vec<PathBuf>

Override the path to the config file (default: the paths ~/.evobench.* where a single one exists where the * is the suffix for one of the supported config file formats (run config-formats to get the list), and if those are missing, use compiled-in default config values)



PostProcessSingle

Do the same “single” post-processing on a single benchmark results as evobench daemon does–useful in case new features were added or the configuration was changed.

Fields

no_stats: bool

Skip (re)generation of the normal evobench.log Excel and flamegraph stats.

run_dir: PathBuf

The path to a directory for an individual run, i.e. ending in a directory name that is a timestamp



PostProcessSummary

Do the same “summary” post-processing on a set of benchmark results as evobench daemon does–useful in case new features were added or the configuration was changed.

Fields

single: bool

Run post-process-single on all sub-directories for the individual runs for this ‘key’, too.

no_single_stats: bool

Skip (re)generation of the normal evobench.log Excel and flamegraph stats. (Only relevant when --single is given.)

no_summary_stats: bool

Skip (re)generation of the normal evobench.log Excel and flamegraph summary stats.

key_dir: PathBuf

The path to a directory for a particular ‘key’, i.e. a set of individual runs: ending in a directory name that is a commit id



Dev

Development commands; these are meant for app development, not for users. Only use when you know what you’re doing. .

Fields

subcommand: DevSubCommand